@@ -20,10 +20,23 @@
 #ifndef GTK_SOURCE_STYLE_SCHEME_PARSER_H
 #define GTK_SOURCE_STYLE_SCHEME_PARSER_H
 
-#include <gdk/gdk.h>
+#include "gtksourcestylescheme.h"
 
 G_BEGIN_DECLS
 
+typedef struct _GtkSourceStyleSchemeBasicInfos GtkSourceStyleSchemeBasicInfos;
+
+struct _GtkSourceStyleSchemeBasicInfos
+{
+	gchar *id;
+	gchar *name;
+	gchar *description;
+	GtkSourceStyleSchemeKind kind;
+};
+
+G_GNUC_INTERNAL
+void		_gtk_source_style_scheme_basic_infos_free		(GtkSourceStyleSchemeBasicInfos *basic_infos);
+
 G_GNUC_INTERNAL
 gboolean	_gtk_source_style_scheme_parser_parse_final_color	(const gchar *color_str,
 									 GdkRGBA     *rgba);
@@ -32,6 +45,12 @@ G_GNUC_INTERNAL
 gboolean	_gtk_source_style_scheme_parser_parse_scale		(const gchar *scale_str,
 									 gdouble     *scale_factor);
 
+G_GNUC_INTERNAL
+gboolean	_gtk_source_style_scheme_parser_parse_file		(GFile                           *file,
+									 GtkSourceStyleSchemeBasicInfos **basic_infos,
+									 GHashTable                     **styles,
+									 GError                         **error);
+
 G_END_DECLS
 
 #endif /* GTK_SOURCE_STYLE_SCHEME_PARSER_H */
