@@ -89,17 +89,17 @@ test_rgba_colors (void)
 	GtkSourceStyleSchemeManager *manager = create_manager ();
 	GtkSourceStyleScheme *scheme = gtk_source_style_scheme_manager_get_scheme (manager, "test");
 	GtkSourceStyle *style_current_line;
-	GtkSourceStyle *style_background_pattern;
+	GtkSourceStyle *style_line_numbers;
 
 	style_current_line = gtk_source_style_scheme_get_style (scheme, "current-line");
-	style_background_pattern = gtk_source_style_scheme_get_style (scheme, "background-pattern");
+	style_line_numbers = gtk_source_style_scheme_get_style (scheme, "line-numbers");
 	g_assert_nonnull (style_current_line);
-	g_assert_nonnull (style_background_pattern);
+	g_assert_nonnull (style_line_numbers);
 
 	g_assert_true (style_current_line->use_background_color);
-	g_assert_true (style_background_pattern->use_background_color);
+	g_assert_true (style_line_numbers->use_background_color);
 	g_assert_true (gdk_rgba_equal (&style_current_line->background_color,
-				       &style_background_pattern->background_color));
+				       &style_line_numbers->background_color));
 
 	g_object_unref (manager);
 }
